@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import json
 import os
-from watson.common import imports
+from watson.common import imports, strings
 from watson.db.contextmanagers import transaction_scope
 
 
@@ -32,3 +32,14 @@ def populate(session, file_name):
                 total += 1
                 session.add(obj)
     return total
+
+
+def save(model, items, fixtures_config):
+    model_name = strings.pluralize(
+        strings.snakecase(model.__name__))
+    path = '{}/{}.json'.format(
+        fixtures_config['path'],
+        model_name)
+    with open(path, 'w') as file:
+        file.write(items)
+    return imports.get_qualified_name(model), path
